@@ -101,7 +101,8 @@ def get_server_objects(
 
 def apply(url: str, manifests_dir: str) -> None:
     """
-    Apply the current manifest file(s) state to the server.
+    Apply the current manifest file state to the server.
+    Excludes systems and registries.
     """
     ingested_manifests = manifests.ingest_manifests(manifests_dir)
 
